@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2014 IBM Corporation and others.
+ * Copyright (c) 2011, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -114,8 +114,8 @@ public class ServletRequestAdvisor extends Object {
 		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
 
 		connection.setInstanceFollowRedirects(false);
-		connection.setConnectTimeout(150 * 1000);
-		connection.setReadTimeout(150 * 1000);
+		connection.setConnectTimeout(150 * 100000);
+		connection.setReadTimeout(150 * 100000);
 		connection.connect();
 
 		InputStream stream = connection.getInputStream();
@@ -281,6 +281,10 @@ public class ServletRequestAdvisor extends Object {
 		connection.setReadTimeout(150 * 1000);
 
 		if (headers != null) {
+			if (headers.containsKey("method")) {
+				connection.setRequestMethod((String)headers.remove("method").get(0));
+			}
+
 			for(Map.Entry<String, List<Object>> entry : headers.entrySet()) {
 				for(Object entryValue : entry.getValue()) {
 					if (entryValue instanceof String) {
@@ -339,7 +343,9 @@ public class ServletRequestAdvisor extends Object {
 
 			writer.append("--" + boundary);
 			writer.append(CRLF);
-			writer.append("Content-Disposition: form-data; name=\"file\"; filename=\"");
+			writer.append("Content-Disposition: form-data; name=\"");
+			writer.append(param);
+			writer.append("\"; filename=\"");
 			writer.append(fileName);
 			writer.append("\"");
 			writer.append(CRLF);
